diff lisp/emacs-lisp/edebug.el @ 3591:507f64624555

Apply typo patches from Paul Eggert.
author Jim Blandy <jimb@redhat.com>
date Wed, 09 Jun 1993 11:59:12 +0000
parents c9689f8d0574
children fd03ee47c0b2
line wrap: on
line diff
--- a/lisp/emacs-lisp/edebug.el	Wed Jun 09 11:33:38 1993 +0000
+++ b/lisp/emacs-lisp/edebug.el	Wed Jun 09 11:59:12 1993 +0000
@@ -127,7 +127,7 @@
 ;;; Reset edebug-mode only on
 ;;; 	first entry of any function at each recursive-edit level.
 ;;; Add edebug-backtrace, to generate cleaned up
 ;;; 	backtrace.  It doesnt "work" like the debug backtrace, however.
 ;;; Require reselecting outside window even if
 ;;; 	quit occurs, otherwise save-excursions may restore
 ;;; 	buffer to the wrong window.
@@ -180,9 +180,9 @@
 ;;; Leave point at syntax error, mark at starting position.
 ;;; 
 ;;; Revision 1.2  88/11/28  12:14:15  liberte
-;;; Bug fixes: cond construct didnt execute.
-;;;   () in sexp list didnt parse
-;;;   () as variable in condition-case didnt parse.
+;;; Bug fixes: cond construct didn't execute.
+;;;   () in sexp list didn't parse
+;;;   () as variable in condition-case didn't parse.
 ;;; 
 ;;; Revision 1.1  88/11/28  12:11:27  liberte
 ;;; Initial revision
@@ -281,7 +281,7 @@
 
 (defun edebug-window-list ()
   "Return a list of windows, in order of next-window."
   ;; This doesnt work for epoch.
   (let* ((first-window (selected-window))
 	 (window-list (list first-window))
 	 (next (next-window first-window)))
@@ -1026,7 +1026,7 @@
     (nreverse value-value-list)))
 
 
 ;; Bug: this doesnt support condition name lists
 (put 'condition-case 'edebug-form-hook
      '(symbolp
        form
@@ -1398,7 +1398,7 @@
 		   (eq edebug-arg-mode 'error)) 
 	       (progn
 		 (setq edebug-mode 'step)
-		 (edebug-overlay-arrow)	; this doesnt always show up.
+		 (edebug-overlay-arrow)	; this doesn't always show up.
 		 (edebug-recursive-edit));;   <<<<<< Recursive edit
 	     )
@@ -127,7 +127,7 @@
 ;;; 	first entry of any function at each recursive-edit level.
 ;;; Add edebug-backtrace, to generate cleaned up
-;;; 	backtrace.  It doesnt "work" like the debug backtrace, however.
+;;; 	backtrace.  It doesn't "work" like the debug backtrace, however.
 ;;; Require reselecting outside window even if
 ;;; 	quit occurs, otherwise save-excursions may restore
@@ -281,7 +281,7 @@
 (defun edebug-window-list ()
   "Return a list of windows, in order of next-window."
-  ;; This doesnt work for epoch.
+  ;; This doesn't work for epoch.
   (let* ((first-window (selected-window))
 	 (window-list (list first-window))
@@ -1026,7 +1026,7 @@
 
 
-;; Bug: this doesnt support condition name lists
+;; Bug: this doesn't support condition name lists
 (put 'condition-case 'edebug-form-hook
      '(symbolp